Class: Harvest::Task
- Inherits:
-
Hashie::Mash
- Object
- Hashie::Mash
- Harvest::Task
- Includes:
- Model
- Defined in:
- lib/harvest/task.rb
Overview
The model that contains information about a task
Fields
[+id+] (READONLY) the id of the task [+name+] (REQUIRED) the name of the task [+billable+] whether the task is billable by default [+deactivated+] whether the task is deactivated [+hourly_rate+] what the default hourly rate for the task is [+default?+] whether to add this task to new projects by default
Instance Method Summary collapse
Methods included from Model
Instance Method Details
#active? ⇒ Boolean
18 19 20 |
# File 'lib/harvest/task.rb', line 18 def active? !deactivated end |